<?php

namespace Metropolitan\Booking\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Metropolitan\Booking\Actions\BookingAction;
use Metropolitan\Booking\Http\Requests\BookingActionRequest;
use Metropolitan\Booking\Http\Resources\BookingResource;
use Metropolitan\Booking\Models\Booking;

/**
 * Admin web controller class.
 */
class BookingActionController extends BaseController
{

    /**
     * Action controller function for booking.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BookingActionRequest $request, Booking $booking, $action)
    {
        try {
            $request = $request->all();
            $booking = BookingAction::run($action, $booking, $request);

            $data = new BookingResource($booking);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('booking::booking.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('booking/booking/' . $booking->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('booking/booking/' . $booking->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
